@@ -25,7 +25,6 @@ class PhpDocNode implements Node
 		$this->children = $children;
 	}
 
-
 	/**
 	 * @return PhpDocTagNode[]
 	 */
@@ -34,7 +33,6 @@ class PhpDocNode implements Node
 		return array_filter($this->children, static fn (PhpDocChildNode $child): bool => $child instanceof PhpDocTagNode);
 	}
 
-
 	/**
 	 * @return PhpDocTagNode[]
 	 */
@@ -43,7 +41,6 @@ class PhpDocNode implements Node
 		return array_filter($this->getTags(), static fn (PhpDocTagNode $tag): bool => $tag->name === $tagName);
 	}
 
-
 	/**
 	 * @return VarTagValueNode[]
 	 */
@@ -55,7 +52,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return ParamTagValueNode[]
 	 */
@@ -67,7 +63,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return TypelessParamTagValueNode[]
 	 */
@@ -79,7 +74,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return ParamImmediatelyInvokedCallableTagValueNode[]
 	 */
@@ -91,7 +85,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return ParamLaterInvokedCallableTagValueNode[]
 	 */
@@ -103,7 +96,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return ParamClosureThisTagValueNode[]
 	 */
@@ -137,7 +129,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return ExtendsTagValueNode[]
 	 */
@@ -149,7 +140,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return ImplementsTagValueNode[]
 	 */
@@ -161,7 +151,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return UsesTagValueNode[]
 	 */
@@ -173,7 +162,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return ReturnTagValueNode[]
 	 */
@@ -185,7 +173,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return ThrowsTagValueNode[]
 	 */
@@ -197,7 +184,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return MixinTagValueNode[]
 	 */
@@ -231,6 +217,17 @@ class PhpDocNode implements Node
 		);
 	}
 
+	/**
+	 * @return SealedTagValueNode[]
+	 */
+	public function getSealedTagValues(string $tagName = '@phpstan-sealed'): array
+	{
+		return array_filter(
+			array_column($this->getTagsByName($tagName), 'value'),
+			static fn (PhpDocTagValueNode $value): bool => $value instanceof SealedTagValueNode,
+		);
+	}
+
 	/**
 	 * @return DeprecatedTagValueNode[]
 	 */
@@ -242,7 +239,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return PropertyTagValueNode[]
 	 */
@@ -254,7 +250,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return PropertyTagValueNode[]
 	 */
@@ -266,7 +261,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return PropertyTagValueNode[]
 	 */
@@ -278,7 +272,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return MethodTagValueNode[]
 	 */
@@ -290,7 +283,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return TypeAliasTagValueNode[]
 	 */
@@ -302,7 +294,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return TypeAliasImportTagValueNode[]
 	 */
@@ -314,7 +305,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return AssertTagValueNode[]
 	 */
@@ -326,7 +316,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return AssertTagPropertyValueNode[]
 	 */
@@ -338,7 +327,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return AssertTagMethodValueNode[]
 	 */
@@ -350,7 +338,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return SelfOutTagValueNode[]
 	 */
@@ -362,7 +349,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	/**
 	 * @return ParamOutTagValueNode[]
 	 */
@@ -374,7 +360,6 @@ class PhpDocNode implements Node
 		);
 	}
 
-
 	public function __toString(): string
 	{
 		$children = array_map(
@@ -387,4 +372,18 @@ class PhpDocNode implements Node
 		return "/**\n *" . implode("\n *", $children) . "\n */";
 	}
 
+	/**
+	 * @param array<string, mixed> $properties
+	 */
+	public static function __set_state(array $properties): self
+	{
+		$instance = new self($properties['children']);
+		if (isset($properties['attributes'])) {
+			foreach ($properties['attributes'] as $key => $value) {
+				$instance->setAttribute($key, $value);
+			}
+		}
+		return $instance;
+	}
+
 }
