@@ -11,11 +11,9 @@ class PhpDocTagNode implements PhpDocChildNode
 
 	use NodeAttributes;
 
-	/** @var string */
-	public $name;
+	public string $name;
 
-	/** @var PhpDocTagValueNode */
-	public $value;
+	public PhpDocTagValueNode $value;
 
 	public function __construct(string $name, PhpDocTagValueNode $value)
 	{
@@ -23,7 +21,6 @@ class PhpDocTagNode implements PhpDocChildNode
 		$this->value = $value;
 	}
 
-
 	public function __toString(): string
 	{
 		if ($this->value instanceof DoctrineTagValueNode) {
@@ -33,4 +30,18 @@ class PhpDocTagNode implements PhpDocChildNode
 		return trim("{$this->name} {$this->value}");
 	}
 
+	/**
+	 * @param array<string, mixed> $properties
+	 */
+	public static function __set_state(array $properties): self
+	{
+		$instance = new self($properties['name'], $properties['value']);
+		if (isset($properties['attributes'])) {
+			foreach ($properties['attributes'] as $key => $value) {
+				$instance->setAttribute($key, $value);
+			}
+		}
+		return $instance;
+	}
+
 }
