@@ -32,4 +32,18 @@ class TypeAliasImportTagValueNode implements PhpDocTagValueNode
 		);
 	}
 
+	/**
+	 * @param array<string, mixed> $properties
+	 */
+	public static function __set_state(array $properties): self
+	{
+		$instance = new self($properties['importedAlias'], $properties['importedFrom'], $properties['importedAs']);
+		if (isset($properties['attributes'])) {
+			foreach ($properties['attributes'] as $key => $value) {
+				$instance->setAttribute($key, $value);
+			}
+		}
+		return $instance;
+	}
+
 }
