@@ -22,7 +22,6 @@ class IntersectionTypeNode implements TypeNode
 		$this->types = $types;
 	}
 
-
 	public function __toString(): string
 	{
 		return '(' . implode(' & ', array_map(static function (TypeNode $type): string {
@@ -34,4 +33,18 @@ class IntersectionTypeNode implements TypeNode
 		}, $this->types)) . ')';
 	}
 
+	/**
+	 * @param array<string, mixed> $properties
+	 */
+	public static function __set_state(array $properties): self
+	{
+		$instance = new self($properties['types']);
+		if (isset($properties['attributes'])) {
+			foreach ($properties['attributes'] as $key => $value) {
+				$instance->setAttribute($key, $value);
+			}
+		}
+		return $instance;
+	}
+
 }
