@@ -49,7 +49,6 @@ class PhpDocParser
 		$this->doctrineConstantExprParser = $constantExprParser->toDoctrine();
 	}
 
-
 	public function parse(TokenIterator $tokens): Ast\PhpDoc\PhpDocNode
 	{
 		$tokens->consumeTokenType(Lexer::TOKEN_OPEN_PHPDOC);
@@ -132,7 +131,6 @@ class PhpDocParser
 		return $this->enrichWithAttributes($tokens, new Ast\PhpDoc\PhpDocNode($children), 1, 0);
 	}
 
-
 	/** @phpstan-impure */
 	private function parseChild(TokenIterator $tokens): Ast\PhpDoc\PhpDocChildNode
 	{
@@ -189,7 +187,6 @@ class PhpDocParser
 		return $tag;
 	}
 
-
 	private function parseText(TokenIterator $tokens): Ast\PhpDoc\PhpDocTextNode
 	{
 		$text = '';
@@ -240,7 +237,6 @@ class PhpDocParser
 		return new Ast\PhpDoc\PhpDocTextNode(trim($text, " \t"));
 	}
 
-
 	private function parseOptionalDescriptionAfterDoctrineTag(TokenIterator $tokens): string
 	{
 		$text = '';
@@ -321,7 +317,6 @@ class PhpDocParser
 		return trim($text, " \t");
 	}
 
-
 	public function parseTag(TokenIterator $tokens): Ast\PhpDoc\PhpDocTagNode
 	{
 		$tag = $tokens->currentTokenValue();
@@ -331,7 +326,6 @@ class PhpDocParser
 		return new Ast\PhpDoc\PhpDocTagNode($tag, $value);
 	}
 
-
 	public function parseTagValue(TokenIterator $tokens, string $tag): Ast\PhpDoc\PhpDocTagValueNode
 	{
 		$startLine = $tokens->currentTokenLine();
@@ -403,6 +397,11 @@ class PhpDocParser
 					$tagValue = $this->parseRequireImplementsTagValue($tokens);
 					break;
 
+				case '@psalm-inheritors':
+				case '@phpstan-sealed':
+					$tagValue = $this->parseSealedTagValue($tokens);
+					break;
+
 				case '@deprecated':
 					$tagValue = $this->parseDeprecatedTagValue($tokens);
 					break;
@@ -520,7 +519,6 @@ class PhpDocParser
 		return $this->enrichWithAttributes($tokens, $tagValue, $startLine, $startIndex);
 	}
 
-
 	private function parseDoctrineTagValue(TokenIterator $tokens, string $tag): Ast\PhpDoc\PhpDocTagValueNode
 	{
 		$startLine = $tokens->currentTokenLine();
@@ -537,7 +535,6 @@ class PhpDocParser
 		);
 	}
 
-
 	/**
 	 * @return list<Doctrine\DoctrineArgument>
 	 */
@@ -573,7 +570,6 @@ class PhpDocParser
 		return $arguments;
 	}
 
-
 	private function parseDoctrineArgument(TokenIterator $tokens): Doctrine\DoctrineArgument
 	{
 		if (!$tokens->isCurrentTokenType(Lexer::TOKEN_IDENTIFIER)) {
@@ -626,7 +622,6 @@ class PhpDocParser
 		}
 	}
 
-
 	/**
 	 * @return DoctrineValueType
 	 */
@@ -716,7 +711,6 @@ class PhpDocParser
 		}
 	}
 
-
 	private function parseDoctrineArrayItem(TokenIterator $tokens): Doctrine\DoctrineArrayItem
 	{
 		$startLine = $tokens->currentTokenLine();
@@ -754,7 +748,6 @@ class PhpDocParser
 		}
 	}
 
-
 	/**
 	 * @return ConstExprIntegerNode|ConstExprStringNode|IdentifierTypeNode|ConstFetchNode
 	 */
@@ -826,7 +819,6 @@ class PhpDocParser
 		return $this->enrichWithAttributes($tokens, $key, $startLine, $startIndex);
 	}
 
-
 	/**
 	 * @return Ast\PhpDoc\ParamTagValueNode|Ast\PhpDoc\TypelessParamTagValueNode
 	 */
@@ -852,7 +844,6 @@ class PhpDocParser
 		return new Ast\PhpDoc\TypelessParamTagValueNode($isVariadic, $parameterName, $description, $isReference);
 	}
 
-
 	private function parseParamImmediatelyInvokedCallableTagValue(TokenIterator $tokens): Ast\PhpDoc\ParamImmediatelyInvokedCallableTagValueNode
 	{
 		$parameterName = $this->parseRequiredVariableName($tokens);
@@ -861,7 +852,6 @@ class PhpDocParser
 		return new Ast\PhpDoc\ParamImmediatelyInvokedCallableTagValueNode($parameterName, $description);
 	}
 
-
 	private function parseParamLaterInvokedCallableTagValue(TokenIterator $tokens): Ast\PhpDoc\ParamLaterInvokedCallableTagValueNode
 	{
 		$parameterName = $this->parseRequiredVariableName($tokens);
@@ -870,7 +860,6 @@ class PhpDocParser
 		return new Ast\PhpDoc\ParamLaterInvokedCallableTagValueNode($parameterName, $description);
 	}
 
-
 	private function parseParamClosureThisTagValue(TokenIterator $tokens): Ast\PhpDoc\ParamClosureThisTagValueNode
 	{
 		$type = $this->typeParser->parse($tokens);
@@ -896,7 +885,6 @@ class PhpDocParser
 		return new Ast\PhpDoc\VarTagValueNode($type, $variableName, $description);
 	}
 
-
 	private function parseReturnTagValue(TokenIterator $tokens): Ast\PhpDoc\ReturnTagValueNode
 	{
 		$type = $this->typeParser->parse($tokens);
@@ -904,7 +892,6 @@ class PhpDocParser
 		return new Ast\PhpDoc\ReturnTagValueNode($type, $description);
 	}
 
-
 	private function parseThrowsTagValue(TokenIterator $tokens): Ast\PhpDoc\ThrowsTagValueNode
 	{
 		$type = $this->typeParser->parse($tokens);
@@ -933,13 +920,19 @@ class PhpDocParser
 		return new Ast\PhpDoc\RequireImplementsTagValueNode($type, $description);
 	}
 
+	private function parseSealedTagValue(TokenIterator $tokens): Ast\PhpDoc\SealedTagValueNode
+	{
+		$type = $this->typeParser->parse($tokens);
+		$description = $this->parseOptionalDescription($tokens, true);
+		return new Ast\PhpDoc\SealedTagValueNode($type, $description);
+	}
+
 	private function parseDeprecatedTagValue(TokenIterator $tokens): Ast\PhpDoc\DeprecatedTagValueNode
 	{
 		$description = $this->parseOptionalDescription($tokens, false);
 		return new Ast\PhpDoc\DeprecatedTagValueNode($description);
 	}
 
-
 	private function parsePropertyTagValue(TokenIterator $tokens): Ast\PhpDoc\PropertyTagValueNode
 	{
 		$type = $this->typeParser->parse($tokens);
@@ -948,7 +941,6 @@ class PhpDocParser
 		return new Ast\PhpDoc\PropertyTagValueNode($type, $parameterName, $description);
 	}
 
-
 	private function parseMethodTagValue(TokenIterator $tokens): Ast\PhpDoc\MethodTagValueNode
 	{
 		$staticKeywordOrReturnTypeOrMethodName = $this->typeParser->parse($tokens);
@@ -1216,7 +1208,6 @@ class PhpDocParser
 		return $parameterName;
 	}
 
-
 	private function parseRequiredVariableName(TokenIterator $tokens): string
 	{
 		$parameterName = $tokens->currentTokenValue();
