@@ -40,6 +40,7 @@ use PHPStan\PhpDocParser\Printer\Printer;
 use PHPUnit\Framework\TestCase;
 use function get_class;
 use function strpos;
+use function var_export;
 use const PHP_EOL;
 
 class TypeParserTest extends TestCase
@@ -57,7 +58,6 @@ class TypeParserTest extends TestCase
 		$this->typeParser = new TypeParser($config, new ConstExprParser($config));
 	}
 
-
 	/**
 	 * @dataProvider provideParseData
 	 * @param TypeNode|Exception $expectedResult
@@ -85,22 +85,23 @@ class TypeParserTest extends TestCase
 
 		$this->assertPrintedNodeViaToString($typeNode);
 		$this->assertPrintedNodeViaPrinter($typeNode);
-	}
 
+		$serialized = var_export($typeNode, true);
+		$readData = eval('return ' . $serialized . ';');
+		$this->assertEquals($typeNode, $readData);
+	}
 
 	private function assertPrintedNodeViaToString(TypeNode $typeNode): void
 	{
 		$this->assertPrintedNode($typeNode, (string) $typeNode);
 	}
 
-
 	private function assertPrintedNodeViaPrinter(TypeNode $typeNode): void
 	{
 		$printer = new Printer();
 		$this->assertPrintedNode($typeNode, $printer->print($typeNode));
 	}
 
-
 	private function assertPrintedNode(TypeNode $typeNode, string $typeNodeString): void
 	{
 		$typeNodeTokens = new TokenIterator($this->lexer->tokenize($typeNodeString));
@@ -110,7 +111,6 @@ class TypeParserTest extends TestCase
 		$this->assertEquals($typeNode, $parsedAgainTypeNode);
 	}
 
-
 	/**
 	 * @dataProvider provideParseData
 	 * @param TypeNode|Exception $expectedResult
@@ -144,8 +144,11 @@ class TypeParserTest extends TestCase
 			$this->unsetAllAttributesButComments($expectedResult),
 			$this->unsetAllAttributesButComments($typeNode),
 		);
-	}
 
+		$serialized = var_export($typeNode, true);
+		$readData = eval('return ' . $serialized . ';');
+		$this->assertEquals($typeNode, $readData);
+	}
 
 	private function unsetAllAttributes(Node $node): Node
 	{
@@ -174,7 +177,6 @@ class TypeParserTest extends TestCase
 		return $traverser->traverse($newNodes)[0];
 	}
 
-
 	private function unsetAllAttributesButComments(Node $node): Node
 	{
 		$visitor = new class extends AbstractNodeVisitor {
@@ -205,7 +207,6 @@ class TypeParserTest extends TestCase
 		return $traverser->traverse($newNodes)[0];
 	}
 
-
 	/**
 	 * @template TNode of Node
 	 * @param TNode $node
@@ -219,7 +220,6 @@ class TypeParserTest extends TestCase
 		return $node;
 	}
 
-
 	/**
 	 * @return array<mixed>
 	 */
@@ -3452,6 +3452,10 @@ class TypeParserTest extends TestCase
 			}
 			$this->assertSame($expectedContent, $content);
 		}
+
+		$serialized = var_export($typeNode, true);
+		$readData = eval('return ' . $serialized . ';');
+		$this->assertEquals($typeNode, $readData);
 	}
 
 }
